package org.apache.commons.lang3.builder;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import org.apache.commons.lang3.Validate;
import org.apache.commons.lang3.builder.Diff;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;

public class DiffResult<T> implements Iterable<Diff<?>> {
  public static final String OBJECTS_SAME_STRING = "";
  
  private static final String DIFFERS_STRING = "differs from";
  
  private final List<Diff<?>> diffList;
  
  private final T lhs;
  
  private final T rhs;
  
  private final ToStringStyle style;
  
  DiffResult(T lhs, T rhs, List<Diff<?>> diffList, ToStringStyle style) {
    Validate.notNull(lhs, "lhs", new Object[0]);
    Validate.notNull(rhs, "rhs", new Object[0]);
    Validate.notNull(diffList, "diffList", new Object[0]);
    this.diffList = diffList;
    this.lhs = lhs;
    this.rhs = rhs;
    if (style == null) {
      this.style = ToStringStyle.DEFAULT_STYLE;
    } else {
      this.style = style;
    } 
  }
  
  public T getLeft() {
    return this.lhs;
  }
  
  public T getRight() {
    return this.rhs;
  }
  
  public List<Diff<?>> getDiffs() {
    return Collections.unmodifiableList(this.diffList);
  }
  
  public int getNumberOfDiffs() {
    return this.diffList.size();
  }
  
  public ToStringStyle getToStringStyle() {
    return this.style;
  }
  
  public String toString() {
    return toString(this.style);
  }
  
  public String toString(ToStringStyle style) {
    if (this.diffList.isEmpty())
      return ""; 
    ToStringBuilder lhsBuilder = new ToStringBuilder(this.lhs, style);
    ToStringBuilder rhsBuilder = new ToStringBuilder(this.rhs, style);
    for (Diff<?> diff : this.diffList) {
      lhsBuilder.append(diff.getFieldName(), diff.getLeft());
      rhsBuilder.append(diff.getFieldName(), diff.getRight());
    } 
    return String.format("%s %s %s", new Object[] { lhsBuilder.build(), "differs from", rhsBuilder
          .build() });
  }
  
  public Iterator<Diff<?>> iterator() {
    return this.diffList.iterator();
  }
}
